@@ -2,7 +2,9 @@ package Perl::Dist::Asset;
 
 # Convenience base class for Perl::Dist assets
 
+use 5.006;
 use strict;
+use warnings;
 use Carp             'croak';
 use File::Spec       ();
 use File::Spec::Unix ();
@@ -12,15 +14,15 @@ use Params::Util     qw{ _STRING _CODELIKE };
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.51';
+	$VERSION = '1.00';
 }
 
 use Object::Tiny qw{
+	parent
 	file
 	url
 	share
 	dist
-	cpan
 };
 
 
@@ -33,30 +35,35 @@ use Object::Tiny qw{
 sub new {
 	my $self = shift->SUPER::new(@_);
 
-	# Map share to url
-	if ( $self->share and ! $self->url ) {
-		my ($dist, $name) = split /\s+/, $self->share;
-		$self->trace("Finding $name in $dist... ");
-		my $file = File::Spec->rel2abs(
-			File::ShareDir::dist_file( $dist, $name )
-		);
-		unless ( -f $file ) {
-			croak("Failed to find $file");
-		}
-		$self->{url} = URI::file->new($file)->as_string;
-		$self->trace(" found\n");
-	}
+	unless ( $self->url ) {
+		if ( $self->share ) {
+			# Map share to url vis File::ShareDir
+			my ($dist, $name) = split /\s+/, $self->share;
+			$self->trace("Finding $name in $dist... ");
+			my $file = File::Spec->rel2abs(
+				File::ShareDir::dist_file( $dist, $name )
+			);
+			unless ( -f $file ) {
+				croak("Failed to find $file");
+			}
+			$self->{url} = URI::file->new($file)->as_string;
+			$self->trace(" found\n");
 
-	# Map dist to url
-	if ( $self->dist and ! $self->url ) {
-		my $dist = $self->dist;
-		$self->trace("Using distribution path $dist\n");
-		my $one  = substr( $self->dist, 0, 1 );
-		my $two  = substr( $self->dist, 1, 1 );
-		my $path = File::Spec::Unix->catfile(
-			'authors', 'id', $one, "$one$two", $dist,
-		);
-		$self->{url} = URI->new_abs( $path, $self->cpan )->as_string;
+		} elsif ( $self->dist ) {
+			# Map CPAN dist path to url
+			my $dist = $self->dist;
+			$self->trace("Using distribution path $dist\n");
+			my $one  = substr( $self->dist, 0, 1 );
+			my $two  = substr( $self->dist, 1, 1 );
+			my $path = File::Spec::Unix->catfile(
+				'authors', 'id', $one, "$one$two", $dist,
+			);
+			$self->{url} = URI->new_abs( $path, $self->cpan )->as_string;
+
+		} elsif ( $self->can('name') and $self->name ) {
+			# Map name to URL via the default package path
+			$self->{url} = $self->parent->binary_url($self->name);
+		}
 	}
 
 	# Check params
@@ -74,6 +81,10 @@ sub new {
 	return $self;
 }
 
+sub cpan {
+	$_[0]->parent->cpan;
+}
+
 
 
 
