@@ -2,123 +2,88 @@ package Perl::Dist::Bootstrap;
 
 use 5.006;
 use strict;
-use base 'Perl::Dist';
+use warnings;
+use base 'Perl::Dist::Vanilla';
 use File::Remove ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.51';
+	$VERSION = '1.00';
 }
 
 
 
 
 
-#####################################################################
-# Configuration
-
-sub app_name             { 'Bootstrap Perl'              }
-sub app_ver_name         { 'Bootstrap Perl Beta 1'       }
-sub app_publisher        { 'Vanilla Perl Project'        }
-sub app_publisher_url    { 'http://vanillaperl.com/'     }
-sub app_id               { 'bootstrapperl'               }
-sub output_base_filename { 'bootstrap-perl-5.8.8-beta-1' }
-
-
-
-
-
 #####################################################################
 # Constructor
 
 # Apply some default paths
 sub new {
-	my $class = shift;
-	return $class->SUPER::new(
-		image_dir => 'C:\\bootperl',
-		temp_dir  => 'C:\\tmp\\bp',
+	shift->SUPER::new(
+		app_id               => 'bootperl',
+		app_name             => 'Bootstrap Perl',
+		image_dir            => 'C:\\bootperl',
 		@_,
 	);
 }
 
-sub run {
-	my $self = shift;
-
-	# Install the main binaries
-	my $t1 = time;
-	$self->install_c_toolchain;
-	my $d1 = time - $t1;
-	$self->trace("Completed install_binaries in $d1 seconds\n");
-
-	# Install the additional C libs
-	my $t6 = time;
-	$self->install_c_libraries;
-	my $d6 = time - $t6;
-	$self->trace("Completed install_libraries in $d6 seconds\n");
-
-	# Install Perl 5.8.8
-	my $t2 = time;
-	$self->install_perl_588;
-	my $d2 = time - $t2;
-	$self->trace("Completed install_perl_588 in $d2 seconds\n");
-
-	# Install the additional modules
-	my $t4 = time;
-	$self->install_perl_modules;
-	my $d4 = time - $t4;
-	$self->trace("Completed install_modules in $d4 seconds\n");
-
-	# Write out the zip
-	my $t5  = time;
-	$self->remove_waste;
-	my $exe = $self->write_exe;
-	my $d5  = time - $t5;
-	$self->trace("Completed write in $d5 seconds\n");
-	$self->trace("Distribution exe file created as $exe\n");
-
-	return 1;
+# Lazily default the full name
+sub app_ver_name {
+	$_[0]->{app_ver_name} or
+	$_[0]->app_name . ' ' . $_[0]->perl_version_human;
 }
 
-sub install_perl_588 {
+# Lazily default the file name
+sub output_base_filename {
+	$_[0]->{output_base_filename} or
+	'bootstrap-perl-' . $_[0]->perl_version_human;
+}
+
+
+
+
+
+#####################################################################
+# Installation Methods
+
+sub install_perl_5100_bin {
 	my $self = shift;
-	$self->SUPER::install_perl_588(@_);
+	$self->SUPER::install_perl_5100_bin(@_);
 
-	# Install the bootperl CPAN::Config
 	$self->install_file(
-		share      => 'Perl-Dist bootperl/CPAN_Config.pm',
+		share      => 'Perl-Dist vanilla/CPAN_Config.pm',
 		install_to => 'perl/lib/CPAN/Config.pm',
 	);
 
 	return 1;
 }
 
+sub install_perl_5100_toolchain_object {
+	Perl::Dist::Util::Toolchain->new(
+		perl_version => $_[0]->perl_version_literal,
+		force        => {
+			'ExtUtils::CBuilder' => 'KWILLIAMS/ExtUtils-CBuilder-0.21.tar.gz',
+		},
+	);
+}
+
+# Install various additional modules
 sub install_perl_modules {
 	my $self = shift;
 
-	# Install the companion Perl modules for the
-	# various libs we installed.
-	$self->install_module(
-		name => 'XML::LibXML',
-	);
-
 	# Install the basics
-	$self->install_module(
-		name => 'Params::Util',
-	);
 	$self->install_module(
 		name => 'Bundle::LWP',
 	);
 
 	# Install various developer tools
-	$self->install_module(
-		name => 'Bundle::CPAN',
-	);
+	#$self->install_module(
+	#	name => 'Bundle::CPAN',
+	#);
 	$self->install_module(
 		name => 'pler',
 	);
-	$self->install_module(
-		name => 'pip',
-	);
 	$self->install_module(
 		name => 'PAR::Dist',
 	);
@@ -144,6 +109,8 @@ sub install_perl_modules {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Perl::Dist::Bootstrap - A bootstrap Perl for building Perl distributions
@@ -153,14 +120,16 @@ Perl::Dist::Bootstrap - A bootstrap Perl for building Perl distributions
 "Bootstrap Perl" is a Perl distribution, and a member of the
 "Vanilla Perl" series of distributions.
 
-The Perl::Dist::Bootstrap module can be used to create a bootstrap
-Perl distribution.
+The L<Perl::Dist::Bootstrap> module can be used in conjunction wit the
+L<perldist> command line tool to create a bootstrap Perl distribution.
 
 Most of the time nobody will be using
 Perl::Dist::Bootstrap directly, but will be downloading the pre-built
 installer for Bootstrap Perl from the Vanilla Perl website at
 L<http://vanillaperl.com/>.
 
+=head2 Why Is This Needed?
+
 For people building Win32 Perl distributions based on L<Perl::Dist>,
 one gotcha is that the distributions have hard-coded install paths.
 
@@ -178,30 +147,26 @@ Perl distribution creation process.
 
 =head2 CONFIGURATION
 
-Bootstrap Perl must be installed in C:\strawberry-perl.  The
+Bootstrap Perl must be installed in C:\bootstrap.  The
 executable installer adds the following environment variable changes:
 
     * adds directories to PATH
-        - C:\strawberry-perl\perl\bin
-        - C:\strawberry-perl\dmake\bin
-        - C:\strawberry-perl\c
-        - C:\strawberry-perl\c\bin
+        - C:\bootstrap\perl\bin
+        - C:\bootstrap\c\bin
 
     * adds directories to LIB
-        - C:\strawberry-perl\c\lib
-        - C:\strawberry-perl\perl\bin
+        - C:\bootstrap\c\lib
+        - C:\bootstrap\perl\bin
 
     * adds directories to INCLUDE 
-        - C:\strawberry-perl\c\include
-        - C:\strawberry-perl\perl\lib\CORE
-        - C:\strawberry-perl\perl\lib\encode
+        - C:\bootstrap\c\include
+        - C:\bootstrap\perl\lib\CORE
 
 LIB and INCLUDE changes are likely more than are necessary, but attempt to
 head off potential problems compiling external programs for use with Perl.
 
-The first time that the "cpan" program is run, users will be prompted for
-configuration settings.  With the defaults provided in Strawberry Perl, users
-may answer "no" to manual configuration and the installation should still work.
+The "cpan" program is pre-configured with a known-good setup, but you may
+wish to reconfigure it.
 
 Manual CPAN configuration may be repeated by running the following command:
 
@@ -209,7 +174,7 @@ Manual CPAN configuration may be repeated by running the following command:
 
 =head1 SUPPORT
 
-Vanilla Perl discussion is centered at L<http://win32.perl.org/>.
+Bootstrap Perl discussion is centered at L<http://win32.perl.org/>.
 
 Other venues for discussion may be listed there.
 
@@ -224,7 +189,7 @@ Adam Kennedy <adamk@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2007 Adam Kennedy.
+Copyright 2007 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
