@@ -1,30 +1,31 @@
 package Perl::Dist::Inno::Script;
 
+use 5.006;
 use strict;
-use Carp                       qw{ croak   };
+use warnings;
+use Carp                       qw{ croak };
 use File::Spec                 ();
 use File::Temp                 ();
 use IPC::Run3                  ();
-use Params::Util               qw{ _STRING };
+use Params::Util               qw{ _STRING _IDENTIFIER };
 use Perl::Dist::Inno::File     ();
 use Perl::Dist::Inno::Icon     ();
 use Perl::Dist::Inno::Registry ();
+use Perl::Dist::Inno::System   ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.51';
+	$VERSION = '1.00';
 }
 
 use Object::Tiny qw{
+	app_id
 	app_name
-	app_ver_name
 	app_publisher
 	app_publisher_url
-	app_id
 	default_group_name
 	default_dir_name
 	output_dir
-	output_base_filename
 	source_dir
 	bin_compil32
 };
@@ -42,7 +43,10 @@ sub new {
 		$self->{default_group_name} = $self->app_name;
 	}
 
-	# Check params
+	# Check and default params
+	unless ( _IDENTIFIER($self->app_id) ) {
+		croak("Missing or invalid app_id param");
+	}
 	unless ( _STRING($self->app_name) ) {
 		croak("Missing or invalid app_name param");
 	}
@@ -55,9 +59,6 @@ sub new {
 	unless ( _STRING($self->app_publisher_url) ) {
 		croak("Missing or invalid app_publisher_uri param");
 	}
-	unless ( _STRING($self->app_id) ) {
-		croak("Missing or invalid app_id param");
-	}
 	unless ( _STRING($self->default_group_name) ) {
 		croak("Missing or invalid default_group_name param");
 	}
@@ -68,7 +69,7 @@ sub new {
 		croak("Missing or invalid output_dir param");
 	}
 	unless ( -d $self->output_dir ) {
-		croak("The output_dir directory does not exist");
+		croak("The output_dir " . $self->output_dir . "directory does not exist");
 	}
 	unless ( -w $self->output_dir ) {
 		croak("The output_dir directory is not writable");
@@ -87,13 +88,14 @@ sub new {
 	$self->{files}    = [];
 	$self->{icons}    = [];
 	$self->{registry} = [];
+	$self->{system}   = [];
 
 	# Find the compil32 program
 	unless ( $ENV{PROGRAMFILES} and -d $ENV{PROGRAMFILES} ) {
 		die("Failed to find the Program Files directory\n");
 	}
-	my $innosetup_dir  = File::Spec->catdir( $ENV{PROGRAMFILES}, "Inno Setup 5" );
-	my $innosetup_file = File::Spec->catfile( $innosetup_dir, 'Compil32.exe' );
+	my $innosetup_dir  = File::Spec->catdir(  $ENV{PROGRAMFILES}, "Inno Setup 5" );
+	my $innosetup_file = File::Spec->catfile( $innosetup_dir,     'Compil32.exe' );
 	unless ( -f $innosetup_file ) {
 		die("Failed to find the Inno Setup Compil32.exe program");
 	}
@@ -102,6 +104,24 @@ sub new {
 	return $self;
 }
 
+# Default the versioned name to an unversioned name
+sub app_ver_name {
+	$_[0]->{app_ver_name} or
+	$_[0]->app_name;
+}
+
+# Default the output filename to the id plus the current date
+sub output_base_filename {
+	$_[0]->{output_base_filename} or
+	$_[0]->app_id . '-' . $_[0]->output_date_string;
+}
+
+# Convenience method
+sub output_date_string {
+	my @t = scalar localtime;
+	return sprintf( "%04d%02d%02d", $t[5] + 1900, $t[4] + 1, $t[3] );
+}
+
 sub files {
 	return @{ $_[0]->{files} };
 }
@@ -114,6 +134,11 @@ sub registry {
 	return @{ $_[0]->{registry} };
 }
 
+sub system {
+	return @{ $_[0]->{system} };
+}
+
+
 
 
 
@@ -168,8 +193,8 @@ sub add_dir {
 	my $self = shift;
 	my $name = shift;
 	$self->add_file(
-		source   => "$name\\*",
-		dest_dir => "{app}\\$name",
+		source             => "$name\\*",
+		dest_dir           => "{app}\\$name",
 		recurse_subdirs    => 1,
 		create_all_subdirs => 1,
 	);
@@ -193,17 +218,6 @@ sub add_uninstall {
 	return 1;
 }
 
-sub add_url {
-	my $self = shift;
-	my $name = shift;
-	my $url  = shift;
-	$self->add_icon(
-		name     => '',
-		filename =>
-	);
-	return 1;
-}
-
 sub add_registry {
 	my $self     = shift;
 	my $registry = Perl::Dist::Inno::Registry->new(@_);
@@ -218,6 +232,27 @@ sub add_env {
 	return 1;
 }
 
+sub add_system {
+	my $self   = shift;
+	my $system = Perl::Dist::Inno::System->new(@_);
+	push @{$self->{system}}, $system;
+	return 1;
+}
+
+sub add_run {
+	my $self   = shift;
+	my $system = Perl::Dist::Inno::System->run(@_);
+	push @{$self->{system}}, $system;
+	return 1;
+}
+
+sub add_uninstallrun {
+	my $self   = shift;
+	my $system = Perl::Dist::Inno::System->uninstallrun(@_);
+	push @{$self->{system}}, $system;
+	return 1;
+}
+
 
 
 
@@ -254,6 +289,7 @@ sub as_string {
 		'; Where the output goes',
 		'OutputDir='          . $self->output_dir,
 		'OutputBaseFilename=' . $self->output_base_filename,
+		'UsePreviousAppDir='  . 'no',
 		'',
 		'; Source location',
 		'SourceDir='          . $self->source_dir,
@@ -266,6 +302,10 @@ sub as_string {
 		'SolidCompression='   . 'yes',
 		'ChangesEnvironment=' . 'yes',
 		'',
+		'; Delete old install',
+		'[InstallDelete]',
+		'Type: filesandordirs; Name: "' . $self->source_dir . '"',
+		'',
 	);
 
 	# Start with only English for now
@@ -296,6 +336,26 @@ sub as_string {
 	}
 	push @lines, '';
 
+	# Add any (optional) entries for [Run]
+	my @run = grep { $_->section eq 'Run' } $self->system;
+	if ( @run ) {
+		push @lines, '[Run]';
+		foreach my $system ( @run ) {
+			push @lines, $system->as_string;
+		}
+		push @lines, '';
+	}
+
+	# Add any (optional) entries for [UninstallRun]
+	my @uninstall = grep { $_->section eq 'UninstallRun' } $self->system;
+	if ( @uninstall ) {
+		push @lines, '[UninstallRun]';
+		foreach my $system ( @uninstall ) {
+			push @lines, $system->as_string;
+		}
+		push @lines, '';
+	}
+
 	# Combine it all
 	return join "\n", @lines;
 }
